import type { AIServiceOptions } from '../../text/types.js';
import type { API } from '../../util/apicall.js';
import { OpenAI } from '../openai/api.js';
import type { OpenAIConfig } from '../openai/types.js';
/**
 * AzureOpenAI: API call details
 * @export
 */
export type AzureOpenAIApiConfig = API & {
    headers: {
        'api-key'?: string;
    };
};
/**
 * AzureOpenAI: Default Model options for text generation
 * @export
 */
export declare const AzureOpenAIDefaultConfig: () => OpenAIConfig;
/**
 * AzureOpenAI: Default model options for more creative text generation
 * @export
 */
export declare const AzureOpenAICreativeConfig: () => OpenAIConfig;
/**
 * AzureOpenAI: Default model options for more fast text generation
 * @export
 */
export declare const AzureOpenAIFastConfig: () => OpenAIConfig;
export declare const AzureOpenAIBestConfig: () => OpenAIConfig;
export interface AzureOpenAIArgs {
    apiKey: string;
    resourceName: string;
    deploymentName: string;
    version?: string;
    config: Readonly<OpenAIConfig>;
    options?: Readonly<AIServiceOptions>;
}
/**
 * AzureOpenAI: AI Service
 * @export
 */
export declare class AzureOpenAI extends OpenAI {
    constructor({ apiKey, resourceName, deploymentName, version, config, options }: Readonly<AzureOpenAIArgs>);
}
