export class AIBalancer {
    services;
    currentServiceIndex = 0;
    currentService;
    constructor(services) {
        if (services.length === 0) {
            throw new Error('No AI services provided.');
        }
        this.services = [...services].sort((a, b) => {
            const aInfo = a.getModelInfo();
            const bInfo = b.getModelInfo();
            const aTotalCost = (aInfo.promptTokenCostPer1M || Infinity) +
                (aInfo.completionTokenCostPer1M || Infinity);
            const bTotalCost = (bInfo.promptTokenCostPer1M || Infinity) +
                (bInfo.completionTokenCostPer1M || Infinity);
            return aTotalCost - bTotalCost;
        });
        const cs = this.services[this.currentServiceIndex];
        if (cs === undefined) {
            throw new Error('Error initializing the AI services.'); // More specific error message
        }
        this.currentService = cs;
    }
    getNextService() {
        const cs = this.services[++this.currentServiceIndex];
        if (cs === undefined) {
            return false;
        }
        this.currentService = cs;
        return true;
    }
    reset() {
        this.currentServiceIndex = 0;
        const cs = this.services[this.currentServiceIndex];
        if (cs === undefined) {
            throw new Error('No AI services provided.');
        }
        this.currentService = cs;
    }
    getName() {
        return this.currentService.getName();
    }
    getModelInfo() {
        return this.currentService.getModelInfo();
    }
    getEmbedModelInfo() {
        return this.currentService.getEmbedModelInfo();
    }
    getModelConfig() {
        return this.currentService.getModelConfig();
    }
    getFeatures() {
        return this.currentService.getFeatures();
    }
    async chat(req, options) {
        this.reset();
        // eslint-disable-next-line no-constant-condition
        while (true) {
            try {
                return await this.currentService.chat(req, options);
            }
            catch (e) {
                if (!this.getNextService()) {
                    throw e;
                }
            }
        }
    }
    async embed(req, options) {
        this.reset();
        // eslint-disable-next-line no-constant-condition
        while (true) {
            try {
                return await this.currentService.embed(req, options);
            }
            catch (e) {
                if (!this.getNextService()) {
                    throw e;
                }
            }
        }
    }
    setOptions(options) {
        this.currentService.setOptions(options);
    }
}
//# sourceMappingURL=balance.js.map