/// <reference types="node" />
import type { ReadableStream } from 'stream/web';
import type { AIPromptConfig, AIService, AIServiceActionOptions, AIServiceOptions } from '../text/types.js';
import { type Span } from '../trace/index.js';
import type { AITextChatRequest, AITextEmbedRequest, TextModelInfoWithProvider } from '../types/index.js';
import { type API } from '../util/apicall.js';
import type { EmbedResponse, TextModelConfig, TextModelInfo, TextResponse } from './types.js';
export interface BaseAIArgs {
    name: string;
    apiURL: string;
    headers: Record<string, string>;
    modelInfo: Readonly<TextModelInfo[]>;
    models: Readonly<{
        model: string;
        embedModel?: string;
    }>;
    options?: Readonly<AIServiceOptions>;
    supportFor: {
        functions: boolean;
        streaming: boolean;
    };
}
export declare const BaseAIDefaultConfig: () => TextModelConfig;
export declare const BaseAIDefaultCreativeConfig: () => TextModelConfig;
export declare class BaseAI<TChatRequest, TEmbedRequest, TChatResponse, TChatResponseDelta, TEmbedResponse> implements AIService {
    generateChatReq?: (req: Readonly<AITextChatRequest>, config: Readonly<AIPromptConfig>) => [API, TChatRequest];
    generateEmbedReq?: (req: Readonly<AITextEmbedRequest>) => [API, TEmbedRequest];
    generateChatResp?: (resp: Readonly<TChatResponse>) => TextResponse;
    generateChatStreamResp?: (resp: Readonly<TChatResponseDelta>, state: object) => TextResponse;
    generateEmbedResp?: (resp: Readonly<TEmbedResponse>) => EmbedResponse;
    private debug;
    private rt?;
    private fetch?;
    private tracer?;
    protected apiURL: string;
    protected name: string;
    protected headers: Record<string, string>;
    protected modelInfo: TextModelInfo;
    protected embedModelInfo?: TextModelInfo;
    protected supportFor: BaseAIArgs['supportFor'];
    constructor({ name, apiURL, headers, modelInfo, models, options, supportFor }: Readonly<BaseAIArgs>);
    setName(name: string): void;
    setAPIURL(apiURL: string): void;
    setHeaders(headers: Record<string, string>): void;
    setOptions(options: Readonly<AIServiceOptions>): void;
    getModelInfo(): Readonly<TextModelInfoWithProvider>;
    getEmbedModelInfo(): TextModelInfoWithProvider | undefined;
    getName(): string;
    getFeatures(): BaseAIArgs['supportFor'];
    getModelConfig(): TextModelConfig;
    chat(_req: Readonly<AITextChatRequest>, options?: Readonly<AIPromptConfig & AIServiceActionOptions>): Promise<TextResponse | ReadableStream<TextResponse>>;
    _chat(_req: Readonly<AITextChatRequest>, options?: Readonly<AIPromptConfig & AIServiceActionOptions>, span?: Span): Promise<TextResponse | ReadableStream<TextResponse>>;
    embed(req: Readonly<AITextEmbedRequest>, options?: Readonly<AIServiceActionOptions>): Promise<EmbedResponse>;
    _embed(req: Readonly<AITextEmbedRequest>, options?: Readonly<AIServiceActionOptions>, span?: Span): Promise<EmbedResponse>;
    private buildHeaders;
}
