import type { AIPromptConfig, AIServiceOptions } from '../../text/types.js';
import type { AITextChatRequest, AITextEmbedRequest } from '../../types/index.js';
import type { API } from '../../util/apicall.js';
import { BaseAI } from '../base.js';
import type { EmbedResponse, TextModelConfig, TextResponse } from '../types.js';
import { type CohereChatRequest, type CohereChatResponse, type CohereChatResponseDelta, type CohereConfig, type CohereEmbedRequest, type CohereEmbedResponse } from './types.js';
/**
 * Cohere: Default Model config for text generation
 * @export
 */
export declare const CohereDefaultConfig: () => CohereConfig;
/**
 * Cohere: Default model config for more creative text generation
 * @export
 */
export declare const CohereCreativeConfig: () => CohereConfig;
export interface CohereArgs {
    apiKey: string;
    config: Readonly<CohereConfig>;
    options?: Readonly<AIServiceOptions>;
}
/**
 * Cohere: AI Service
 * @export
 */
export declare class Cohere extends BaseAI<CohereChatRequest, CohereEmbedRequest, CohereChatResponse, CohereChatResponseDelta, CohereEmbedResponse> {
    private config;
    constructor({ apiKey, config, options }: Readonly<CohereArgs>);
    getModelConfig(): TextModelConfig;
    generateChatReq: (req: Readonly<AITextChatRequest>, _config: Readonly<AIPromptConfig>) => [API, CohereChatRequest];
    generateEmbedReq: (req: Readonly<AITextEmbedRequest>) => [API, CohereEmbedRequest];
    generateChatResp: (resp: Readonly<CohereChatResponse>) => TextResponse;
    generateChatStreamResp: (resp: Readonly<CohereChatResponseDelta>, state: object) => TextResponse;
    generateEmbedResp: (resp: Readonly<CohereEmbedResponse>) => EmbedResponse;
}
