import { BaseAIDefaultConfig, BaseAIDefaultCreativeConfig } from '../base.js';
import { OpenAI } from '../openai/api.js';
import { DeepSeekModel } from './types.js';
/**
 * DeepSeek: Default Model options for text generation
 * @export
 */
export const DeepSeekDefaultConfig = () => structuredClone({
    model: DeepSeekModel.DeepSeekChat,
    ...BaseAIDefaultConfig()
});
/**
 * DeepSeek: Default Model options for text generation
 * @export
 */
export const DeepSeekCodeConfig = () => structuredClone({
    model: DeepSeekModel.DeepSeekCoder,
    ...BaseAIDefaultCreativeConfig()
});
/**
 * DeepSeek: AI Service
 * @export
 */
export class DeepSeek extends OpenAI {
    constructor({ apiKey, config = DeepSeekDefaultConfig(), options }) {
        if (!apiKey || apiKey === '') {
            throw new Error('DeepSeek API key not set');
        }
        super({
            apiKey,
            config,
            options,
            apiURL: 'https://api.deepseek.com'
        });
        super.setName('DeepSeek');
    }
}
//# sourceMappingURL=api.js.map