import type { AIServiceOptions } from '../../text/types.js';
import type { AITextChatRequest, AITextEmbedRequest } from '../../types/index.js';
import type { API } from '../../util/apicall.js';
import { BaseAI } from '../base.js';
import type { EmbedResponse, TextModelConfig, TextResponse } from '../types.js';
import { type GoogleGeminiBatchEmbedRequest, type GoogleGeminiBatchEmbedResponse, type GoogleGeminiChatRequest, type GoogleGeminiChatResponse, type GoogleGeminiChatResponseDelta, type GoogleGeminiConfig } from './types.js';
/**
 * GoogleGemini: Default Model options for text generation
 * @export
 */
export declare const GoogleGeminiDefaultConfig: () => GoogleGeminiConfig;
export declare const GoogleGeminiDefaultCreativeConfig: () => GoogleGeminiConfig;
export interface GoogleGeminiArgs {
    apiKey: string;
    projectId?: string;
    region?: string;
    config: Readonly<GoogleGeminiConfig>;
    options?: Readonly<AIServiceOptions>;
}
/**
 * GoogleGemini: AI Service
 * @export
 */
export declare class GoogleGemini extends BaseAI<GoogleGeminiChatRequest, GoogleGeminiBatchEmbedRequest, GoogleGeminiChatResponse, GoogleGeminiChatResponseDelta, GoogleGeminiBatchEmbedResponse> {
    private config;
    private apiKey;
    constructor({ apiKey, projectId, region, config, options }: Readonly<GoogleGeminiArgs>);
    getModelConfig(): TextModelConfig;
    generateChatReq: (req: Readonly<AITextChatRequest>) => [API, GoogleGeminiChatRequest];
    generateEmbedReq: (req: Readonly<AITextEmbedRequest>) => [API, GoogleGeminiBatchEmbedRequest];
    generateChatResp: (resp: Readonly<GoogleGeminiChatResponse>) => TextResponse;
    generateChatStreamResp: (resp: Readonly<GoogleGeminiChatResponseDelta>) => TextResponse;
    generateEmbedResp: (resp: Readonly<GoogleGeminiBatchEmbedResponse>) => EmbedResponse;
}
