import { BaseAIDefaultConfig } from '../base.js';
import { OpenAI } from '../openai/api.js';
/**
 * GroqAI: Default Model options for text generation
 * @export
 */
export const GroqDefaultConfig = () => structuredClone({
    model: 'llama2-70b-4096',
    ...BaseAIDefaultConfig()
});
/**
 * GroqAI: AI Service
 * @export
 */
export class Groq extends OpenAI {
    constructor({ apiKey, config = GroqDefaultConfig(), options }) {
        if (!apiKey || apiKey === '') {
            throw new Error('Groq API key not set');
        }
        super({
            apiKey,
            config,
            options: { ...options, streamingUsage: false },
            apiURL: 'https://api.groq.com/openai/v1'
        });
        super.setName('Groq');
    }
}
//# sourceMappingURL=api.js.map