import { Anthropic } from './anthropic/api.js';
import { AzureOpenAI } from './azure-openai/api.js';
import { Cohere } from './cohere/api.js';
import { DeepSeek } from './deepseek/api.js';
import { GoogleGemini } from './google-gemini/api.js';
import { Groq } from './groq/api.js';
import { HuggingFace } from './huggingface/api.js';
import { Mistral } from './mistral/api.js';
import { Ollama } from './ollama/api.js';
import { OpenAI } from './openai/api.js';
import { Together } from './together/api.js';
export * from './openai/index.js';
export * from './azure-openai/index.js';
export * from './huggingface/index.js';
export * from './together/index.js';
export * from './cohere/index.js';
export * from './google-gemini/index.js';
export * from './anthropic/index.js';
export * from './groq/index.js';
export * from './mistral/index.js';
export * from './deepseek/index.js';
export * from './ollama/index.js';
export * from './types.js';
export * from './balance.js';
export * from './base.js';
export const AI = (name, options) => {
    switch (name) {
        case 'openai':
            return new OpenAI(options);
        case 'azure-openai':
            return new AzureOpenAI(options);
        case 'huggingface':
            return new HuggingFace(options);
        case 'groq':
            return new Groq(options);
        case 'together':
            return new Together(options);
        case 'cohere':
            return new Cohere(options);
        case 'google-gemini':
            return new GoogleGemini(options);
        case 'anthropic':
            return new Anthropic(options);
        case 'mistral':
            return new Mistral(options);
        case 'deepseek':
            return new DeepSeek(options);
        case 'ollama':
            return new Ollama(options);
        default:
            throw new Error(`Unknown AI ${name}`);
    }
};
//# sourceMappingURL=index.js.map