import { BaseAIDefaultConfig } from '../base.js';
import { OpenAI } from '../openai/api.js';
import { MistralModel } from './types.js';
/**
 * Mistral: Default Model options for text generation
 * @export
 */
export const MistralDefaultConfig = () => structuredClone({
    model: MistralModel.MistralSmall,
    ...BaseAIDefaultConfig()
});
/**
 * Mistral: Default model options to use the more advanced model
 * @export
 */
export const MistralBestConfig = () => structuredClone({
    ...MistralDefaultConfig(),
    model: MistralModel.MistralLarge
});
/**
 * Mistral: AI Service
 * @export
 */
export class Mistral extends OpenAI {
    constructor({ apiKey, config = MistralDefaultConfig(), options }) {
        if (!apiKey || apiKey === '') {
            throw new Error('Mistral API key not set');
        }
        super({
            apiKey,
            config,
            options,
            apiURL: 'https://api.mistral.ai/v1'
        });
        super.setName('Mistral');
    }
}
//# sourceMappingURL=api.js.map