import type { AIPromptConfig, AIServiceOptions } from '../../text/types.js';
import type { AITextChatRequest, AITextEmbedRequest } from '../../types/index.js';
import type { API } from '../../util/apicall.js';
import { BaseAI } from '../base.js';
import type { EmbedResponse, TextModelConfig, TextResponse } from '../types.js';
import { type OpenAIChatRequest, type OpenAIChatResponse, type OpenAIChatResponseDelta, type OpenAIConfig, type OpenAIEmbedRequest, type OpenAIEmbedResponse } from './types.js';
/**
 * OpenAI: Default Model options for text generation
 * @export
 */
export declare const OpenAIDefaultConfig: () => OpenAIConfig;
/**
 * OpenAI: Default model options to use the more advanced model
 * @export
 */
export declare const OpenAIBestConfig: () => OpenAIConfig;
/**
 * OpenAI: Default model options for more creative text generation
 * @export
 */
export declare const OpenAICreativeConfig: () => OpenAIConfig;
/**
 * OpenAI: Default model options for more fast text generation
 * @export
 */
export declare const OpenAIFastConfig: () => OpenAIConfig;
export interface OpenAIArgs {
    apiKey: string;
    apiURL?: string;
    config?: Readonly<OpenAIConfig>;
    options?: Readonly<AIServiceOptions & {
        streamingUsage?: boolean;
    }>;
}
/**
 * OpenAI: AI Service
 * @export
 */
export declare class OpenAI extends BaseAI<OpenAIChatRequest, OpenAIEmbedRequest, OpenAIChatResponse, OpenAIChatResponseDelta, OpenAIEmbedResponse> {
    private config;
    private streamingUsage;
    constructor({ apiKey, config, options, apiURL }: Readonly<OpenAIArgs>);
    getModelConfig(): TextModelConfig;
    generateChatReq: (req: Readonly<AITextChatRequest>, _config: Readonly<AIPromptConfig>) => [API, OpenAIChatRequest];
    generateEmbedReq: (req: Readonly<AITextEmbedRequest>) => [API, OpenAIEmbedRequest];
    generateChatResp: (resp: Readonly<OpenAIChatResponse>) => TextResponse;
    generateChatStreamResp: (resp: Readonly<OpenAIChatResponseDelta>, state: object) => TextResponse;
    generateEmbedResp: (resp: Readonly<OpenAIEmbedResponse>) => EmbedResponse;
}
