/// <reference types="node" />
import { type Span, type Tracer } from '../trace/index.js';
import type { DBQueryRequest, DBQueryResponse, DBService, DBUpsertRequest, DBUpsertResponse } from './types.js';
export interface BaseArgs {
    fetch?: typeof fetch;
    tracer?: Tracer;
}
export interface BaseOpOptions {
    span?: Span;
}
export declare class BaseDB implements DBService {
    protected name: string;
    protected fetch?: typeof fetch;
    private tracer?;
    _upsert?: (req: Readonly<DBUpsertRequest>, update?: boolean, options?: Readonly<BaseOpOptions>) => Promise<DBUpsertResponse>;
    _batchUpsert?: (batchReq: Readonly<DBUpsertRequest[]>, update?: boolean, options?: Readonly<BaseOpOptions>) => Promise<DBUpsertResponse>;
    _query?: (req: Readonly<DBQueryRequest>, options?: Readonly<BaseOpOptions>) => Promise<DBQueryResponse>;
    constructor({ name, fetch, tracer }: Readonly<BaseArgs & {
        name: string;
    }>);
    upsert(req: Readonly<DBUpsertRequest>, update?: boolean): Promise<DBUpsertResponse>;
    batchUpsert(req: Readonly<DBUpsertRequest[]>, update?: boolean): Promise<DBUpsertResponse>;
    query(req: Readonly<DBQueryRequest>): Promise<DBQueryResponse>;
}
