import { apiCall } from '../util/apicall.js';
import { BaseDB } from './base.js';
const createPineconeQueryRequest = (req) => {
    const pineconeQueryRequest = {
        namespace: req.namespace,
        topK: req.limit || 10,
        filter: {},
        includeValues: true,
        includeMetadata: true,
        vector: req.values ?? [],
        id: req.id
    };
    return pineconeQueryRequest;
};
/**
 * Pinecone: DB Service
 * @export
 */
export class Pinecone extends BaseDB {
    apiKey;
    apiURL;
    constructor({ apiKey, host, fetch, tracer }) {
        if (!apiKey || apiKey === '') {
            throw new Error('Pinecone API key not set');
        }
        super({ name: 'Pinecone', fetch, tracer });
        this.apiKey = apiKey;
        this.apiURL = host;
    }
    _upsert = async (req, update, options) => {
        await this._batchUpsert([req], update, options);
        return { ids: [req.id] };
    };
    _batchUpsert = async (batchReq, _update, options) => {
        if (batchReq.length === 0) {
            throw new Error('Batch request is empty');
        }
        await apiCall({
            url: this.apiURL,
            headers: { Authorization: `Bearer ${this.apiKey}` },
            name: '/vectors/upsert',
            fetch: this.fetch,
            span: options?.span
        }, batchReq.map(({ id, values = [], metadata }) => ({
            id,
            values,
            metadata
        })));
        return { ids: batchReq.map(({ id }) => id) };
    };
    query = async (req, options) => {
        if (req.text) {
            throw new Error('Pinecone does not support text');
        }
        const res = (await apiCall({
            url: this.apiURL,
            headers: { Authorization: `Bearer ${this.apiKey}` },
            name: '/query',
            fetch: this.fetch,
            span: options?.span
        }, createPineconeQueryRequest(req)));
        const matches = res.matches.map(({ id, score, values, metadata }) => ({
            id,
            score,
            metadata,
            values
        }));
        return { matches };
    };
}
//# sourceMappingURL=pinecone.js.map