import { type AIService, type DBService, type Program } from '../index.js';
export type RewriteIn = {
    query: string;
};
export type RewriteOut = {
    rewrittenQuery: string;
};
export type RerankerIn = {
    query: string;
    items: string[];
};
export type RerankerOut = {
    rankedItems: string[];
};
export interface DBLoaderOptions {
    chunker?: (text: string) => string[];
    rewriter?: Program<RewriteIn, RewriteOut>;
    reranker?: Program<RerankerIn, RerankerOut>;
}
export interface DBManagerArgs {
    ai: AIService;
    db: DBService;
    config?: DBLoaderOptions;
}
export interface Match {
    score: number;
    text: string;
}
export declare class DBManager {
    private ai;
    private db;
    private chunker;
    private rewriter?;
    private reranker?;
    constructor({ ai, db, config }: Readonly<DBManagerArgs>);
    private defaultChunker;
    insert: (text: Readonly<string | string[]>, options?: Readonly<{
        batchSize?: number;
        maxWordsPerChunk?: number;
        minWordsPerChunk?: number;
    }>) => Promise<void>;
    query: (query: Readonly<string | string[] | number | number[]>, { topPercent }?: Readonly<{
        topPercent?: number;
    }> | undefined) => Promise<Match[][]>;
}
