import { updateProgressBar } from './util.js';
export class TestPrompt {
    program;
    examples;
    constructor({ program, examples = [] }) {
        if (examples.length == 0) {
            throw new Error('No examples found');
        }
        this.program = program;
        this.examples = examples;
    }
    async run(metricFn) {
        const st = new Date().getTime();
        const total = this.examples.length;
        let successCount = 0;
        for (let i = 0; i < total; i++) {
            const ex = this.examples[i];
            if (!ex) {
                throw new Error('Invalid example');
            }
            const res = await this.program.forward(ex);
            const success = metricFn({ prediction: res, example: ex });
            if (success) {
                successCount++;
            }
            const et = new Date().getTime() - st;
            updateProgressBar(i, total, successCount, et, 30, 'Testing Prompt');
        }
        console.log('\nPerformance: ', successCount, '/', total, 'Accuracy: ', successCount / total, '\n');
    }
}
//# sourceMappingURL=evaluate.js.map