import type { TextResponseFunctionCall } from '../ai/index.js';
import { type AITextFunction, Memory } from '../text/index.js';
import type { AIService } from '../text/index.js';
import { type AITextChatRequest } from '../types/index.js';
import { type Assertion, type StreamingAssertion } from './asserts.js';
import { type GenIn, type GenOut, Program, type ProgramForwardOptions, type Value } from './program.js';
import { PromptTemplate } from './prompt.js';
import { Signature } from './sig.js';
export interface GenerateOptions {
    functions?: AITextFunction[];
    functionCall?: AITextChatRequest['functionCall'];
    promptTemplate?: typeof PromptTemplate;
    asserts?: Assertion[];
    streamingAsserts?: StreamingAssertion[];
}
export type GenerateResult<OUT extends GenOut> = OUT & {
    functions?: TextResponseFunctionCall[];
};
export declare class Generate<IN extends GenIn = GenIn, OUT extends GenerateResult<GenOut> = GenerateResult<GenOut>> extends Program<IN, OUT> {
    private signature;
    private sigHash;
    private ai;
    private pt;
    private asserts;
    private streamingAsserts;
    private options?;
    private funcProc?;
    private functionList?;
    constructor(ai: AIService, signature: Readonly<Signature | string>, options?: Readonly<GenerateOptions>);
    private updateSigForFunctions;
    private _setExamples;
    setExamples(examples: Readonly<Record<string, Value>[]>): void;
    addAssert: (fn: Assertion['fn'], message?: string, optional?: boolean) => void;
    addStreamingAssert: (fieldName: string, fn: StreamingAssertion['fn'], message?: string, optional?: boolean) => void;
    private forwardSendRequest;
    private forwardCore;
    private processSteamingResponse;
    private processResponse;
    private _forward;
    forward(values: IN, options?: Readonly<ProgramForwardOptions>): Promise<OUT>;
    processFunctions: (functionCalls: readonly TextResponseFunctionCall[], mem: Readonly<Memory>, sessionId?: string, traceId?: string) => Promise<void>;
}
