import type { TextModelConfig, TextResponse } from '../ai/types.js';
import type { AIMemory, AIService } from '../text/types.js';
import type { Tracer } from '../trace/index.js';
import { type Field } from './sig.js';
export type Value = string | string[] | number | boolean | object;
export type GenIn = Record<string, Value>;
export type GenOut = Record<string, Value>;
export type ProgramTrace = {
    trace: Record<string, Value>;
    key: string;
};
export type ProgramDemos = {
    traces: Record<string, Value>[];
    key: string;
};
export type ProgramForwardOptions = {
    maxCompletions?: number;
    maxRetries?: number;
    maxSteps?: number;
    mem?: AIMemory;
    ai?: AIService;
    modelConfig?: TextModelConfig;
    sessionId?: string;
    traceId?: string | undefined;
    tracer?: Tracer;
    stream?: boolean;
    debug?: boolean;
};
export interface ITunable {
    setExamples: (examples: Readonly<Record<string, Value>[]>) => void;
    setTrace: (trace: Record<string, Value>) => void;
    updateKey: (parentKey: string) => void;
    getTraces: () => ProgramTrace[];
    setDemos: (demos: readonly ProgramDemos[]) => void;
    loadDemos: (filename: string) => void;
}
export interface IUsable {
    getUsage: () => ProgramUsage[];
    resetUsage: () => void;
}
export type ProgramUsage = TextResponse['modelUsage'] & {
    ai: string;
    model: string;
};
export declare class Program<IN extends GenIn, OUT extends GenOut> implements ITunable, IUsable {
    private key;
    private reg;
    protected examples?: Record<string, Value>[];
    protected demos?: Record<string, Value>[];
    protected trace?: Record<string, Value>;
    protected usage: ProgramUsage[];
    constructor();
    register(prog: Readonly<ITunable & IUsable>): void;
    forward(_arg0: IN, _options?: Readonly<ProgramForwardOptions>): Promise<OUT>;
    setExamples(examples: Readonly<Record<string, Value>[]>): void;
    setTrace(trace: Record<string, Value>): void;
    updateKey(parentKey: string): void;
    getTraces(): ProgramTrace[];
    getUsage(): ProgramUsage[];
    resetUsage(): void;
    setDemos(demos: readonly ProgramDemos[]): void;
    loadDemos(filename: string): void;
}
export declare const validateValue: (field: Readonly<Field>, value: Readonly<Value>) => void;
