import { readFileSync } from 'fs';
import { InstanceRegistry } from './registry.js';
import {} from './sig.js';
export class Program {
    key;
    reg;
    examples;
    demos;
    trace;
    usage = [];
    constructor() {
        this.reg = new InstanceRegistry();
        this.key = this.constructor.name;
    }
    register(prog) {
        if (this.key) {
            prog.updateKey(this.key);
        }
        this.reg.register(prog);
    }
    async forward(
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    _arg0, 
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    _options) {
        throw new Error('forward() not implemented');
    }
    setExamples(examples) {
        for (const inst of this.reg) {
            inst.setExamples(examples);
        }
    }
    setTrace(trace) {
        this.trace = trace;
    }
    updateKey(parentKey) {
        this.key = [parentKey, this.key].join('/');
    }
    getTraces() {
        let traces = [];
        if (this.trace) {
            traces.push({
                trace: this.trace,
                // examples: this.examples ?? [],
                key: this.key
            });
        }
        for (const inst of this.reg) {
            const _traces = inst.getTraces();
            traces = [...traces, ..._traces];
        }
        return traces;
    }
    getUsage() {
        let usage = [...(this.usage ?? [])];
        for (const inst of this.reg) {
            const cu = inst.getUsage();
            usage = [...usage, ...cu];
        }
        return mergeProgramUsage(usage);
    }
    resetUsage() {
        this.usage = [];
        for (const inst of this.reg) {
            inst.resetUsage();
        }
    }
    setDemos(demos) {
        const ourDemos = demos.find((v) => v.key === this.key);
        this.demos = ourDemos?.traces;
        for (const inst of this.reg) {
            inst.setDemos(demos);
        }
    }
    loadDemos(filename) {
        const buf = readFileSync(filename, 'utf-8');
        this.setDemos(JSON.parse(buf));
    }
}
export const validateValue = (field, value) => {
    const ft = field.type ?? { name: 'string', isArray: false };
    const validateSingleValue = (expectedType, val) => {
        switch (expectedType) {
            case 'string':
                return typeof val === 'string';
            case 'number':
                return typeof val === 'number';
            case 'boolean':
                return typeof val === 'boolean';
            default:
                return false; // Unknown or unsupported type
        }
    };
    let isValid = true;
    if (ft.isArray) {
        if (!Array.isArray(value)) {
            isValid = false;
        }
        else {
            for (const item of value) {
                if (!validateSingleValue(ft.name, item)) {
                    isValid = false;
                    break;
                }
            }
        }
    }
    else {
        isValid = validateSingleValue(ft.name, value);
    }
    if (!isValid) {
        throw new Error(`Validation failed: Expected '${field.name}' to be a ${ft.isArray ? 'an array of ' : ''}${ft.name} instead got '${value}'`);
    }
};
function mergeProgramUsage(usages) {
    const usageMap = {};
    usages.forEach((usage) => {
        const key = `${usage.ai}:${usage.model}`;
        if (!usageMap[key]) {
            usageMap[key] = { ...usage };
            return;
        }
        usageMap[key].promptTokens += usage.promptTokens;
        usageMap[key].completionTokens += usage.completionTokens;
        usageMap[key].totalTokens += usage.totalTokens;
    });
    return Object.values(usageMap);
}
//# sourceMappingURL=program.js.map