import { existsSync } from 'fs';
import { MemoryDB } from '../db/memory.js';
import { ColorLog } from '../util/log.js';
const colorLog = new ColorLog();
export class Route {
    name;
    context;
    constructor(name, context) {
        this.name = name;
        this.context = context;
    }
    getName() {
        return this.name;
    }
    getContext() {
        return this.context;
    }
}
export class Router {
    ai;
    db;
    debug;
    constructor(ai) {
        this.db = new MemoryDB();
        this.ai = ai;
    }
    setRoutes = async (routes, options) => {
        const fn = options?.filename;
        if (fn && existsSync(fn)) {
            await this.db.load(fn);
        }
        for (const ro of routes) {
            const ret = await this.ai.embed({ texts: ro.getContext() });
            await this.db.upsert({
                id: ro.getName(),
                table: 'routes',
                values: ret.embeddings[0]
            });
        }
        if (fn) {
            await this.db.save();
        }
    };
    async forward(text, options) {
        const { embeddings } = await this.ai.embed({ texts: [text] });
        const matches = await this.db.query({
            table: 'routes',
            values: embeddings[0]
        });
        let m = matches.matches;
        if (typeof options?.cutoff === 'number') {
            const { cutoff } = options;
            m = m.filter((m) => m.score <= cutoff);
        }
        if (this.debug) {
            console.log(colorLog.whiteBright(`query: ${text}`) +
                '\n' +
                colorLog.greenBright(JSON.stringify(m.map((m) => `${m.id}, ${m.score}`))));
        }
        const route = m.at(0);
        if (!route) {
            return '';
        }
        return route.id;
    }
    setOptions(options) {
        if (typeof options.debug === 'boolean') {
            this.debug = options.debug;
        }
    }
}
//# sourceMappingURL=router.js.map