export const trimNonAlphaNum = (str) => {
    return str.replace(/^\W+|\W+$/g, '');
};
export const splitIntoTwo = (str, separator) => {
    const index = str.search(separator);
    if (index === -1) {
        return [str]; // No separator found, return the original string as the only part
    }
    const matchResult = str.match(separator);
    if (!matchResult) {
        throw new Error('Match failed unexpectedly.');
    }
    const firstPart = str.substring(0, index);
    const secondPart = str.substring(index + matchResult[0].length);
    return [firstPart, secondPart];
};
export const dedup = (seq) => {
    const seen = new Set();
    const result = [];
    for (const x of seq) {
        if (!seen.has(x)) {
            seen.add(x);
            result.push(x);
        }
    }
    return result;
};
export const extractIdAndText = (input) => {
    const match = input.match(/^(\d+)[.,\s]+(.*)$/);
    if (!match || match.length < 3) {
        throw new Error('line must start with a number, a dot and then text. e.g. "1. hello"');
    }
    const id = parseInt(match[1], 10);
    const text = match[2].trim();
    return { id, text };
};
export const extractIndexPrefixedText = (input) => {
    const match = input.match(/^(\d+)[.,\s]+(.*)$/);
    // Check if match is not null and if the second capturing group is present
    if (match && match[2] !== undefined) {
        return match[2].trim();
    }
    return input;
};
export const batchArray = (arr, size) => {
    const chunkedArr = [];
    for (let i = 0; i < arr.length; i += size) {
        chunkedArr.push(arr.slice(i, i + size));
    }
    return chunkedArr;
};
//# sourceMappingURL=strutil.js.map