import { AI, BootstrapFewShot, ChainOfThought, emScore, HFDataLoader, RAG } from '../index.js';
const hf = new HFDataLoader();
const examples = await hf.getData({
    dataset: 'hotpot_qa',
    split: 'train',
    count: 100,
    fields: ['question', 'answer']
});
const ai = AI('openai', { apiKey: process.env.OPENAI_APIKEY });
const fetchFromVectorDB = async (query) => {
    const cot = new ChainOfThought(ai, 'query -> answer');
    const { answer } = await cot.forward({ query });
    return answer;
};
// Setup the program to tune
const program = new RAG(ai, fetchFromVectorDB, { maxHops: 3 });
// Setup a Bootstrap Few Shot optimizer to tune the above program
const optimize = new BootstrapFewShot({
    program,
    examples
});
// Setup a evaluation metric em, f1 scores are a popular way measure retrieval performance.
const metricFn = ({ prediction, example }) => {
    return emScore(prediction.answer, example.answer);
};
// Run the optimizer and save the result
await optimize.compile(metricFn, { filename: 'demos.json' });
console.log('> done. test with qna-use-tuned.ts');
//# sourceMappingURL=qna-tune.js.map