import { Signature } from '../dsp/index.js';
import { Program } from '../dsp/program.js';
import {} from '../text/index.js';
import { SpanKind } from '../trace/index.js';
import { ChainOfThought } from './cot.js';
import { ReAct } from './react.js';
export class Agent extends Program {
    gen;
    name;
    description;
    subAgentList;
    func;
    constructor(ai, { name, description, signature, agents, functions }, options) {
        super();
        const sig = new Signature(signature);
        const funcs = [
            ...(functions ?? []),
            ...(agents?.map((a) => a.getFunction()) ?? [])
        ];
        const opt = {
            promptTemplate: options?.promptTemplate,
            asserts: options?.asserts,
            functions: funcs
        };
        this.gen =
            funcs.length > 0
                ? new ReAct(ai, sig, opt)
                : new ChainOfThought(ai, sig, opt);
        this.name = name;
        this.description = description;
        this.subAgentList = agents?.map((a) => a.getFunction().name).join(', ');
        this.func = {
            name: this.name,
            description: this.description,
            parameters: sig.toJSONSchema(),
            func: () => this.forward
        };
        this.register(this.gen);
        for (const agent of agents ?? []) {
            this.register(agent);
        }
    }
    getFunction() {
        return this.func;
    }
    async forward(values, options) {
        if (!options?.tracer) {
            return await this.gen.forward(values, options);
        }
        const attributes = {
            ['agent.name']: this.name,
            ['agent.description']: this.description,
            ['agent.subAgents']: this.subAgentList ?? 'none'
        };
        return await options?.tracer.startActiveSpan('Agent', {
            kind: SpanKind.SERVER,
            attributes
        }, async (span) => {
            const res = await this.gen.forward(values, options);
            span.end();
            return res;
        });
    }
}
//# sourceMappingURL=agent.js.map