import { dedup, Generate, Signature } from '../dsp/index.js';
import {} from '../dsp/program.js';
import { ChainOfThought } from './cot.js';
export class RAG extends ChainOfThought {
    genQuery;
    queryFn;
    maxHops;
    constructor(ai, queryFn, options) {
        const sig = '"Answer questions with short factoid answers." context:string[] "may contain relevant facts", question -> answer';
        super(ai, sig, options);
        this.maxHops = options?.maxHops ?? 3;
        const qsig = new Signature('"Write a simple search query that will help answer a complex question." context?:string[] "may contain relevant facts", question -> query "question to further our understanding"');
        this.genQuery = new Generate(ai, qsig);
        this.queryFn = queryFn;
        this.register(this.genQuery);
    }
    async forward({ question }, options) {
        let context = [];
        for (let i = 0; i < this.maxHops; i++) {
            const { query } = await this.genQuery.forward({
                context,
                question
            }, options);
            const val = await this.queryFn(query);
            context = dedup([...context, val]);
        }
        return super.forward({ context, question }, options);
    }
}
//# sourceMappingURL=rag.js.map