import JSON5 from 'json5';
import { validateJSONSchema } from './jsonschema.js';
export class FunctionProcessor {
    funcList;
    constructor(funcList) {
        funcList
            .filter((v) => v.parameters)
            .forEach((v) => validateJSONSchema(v.parameters));
        this.funcList = funcList;
    }
    executeFunction = async (fnSpec, func, options) => {
        if (!fnSpec.func) {
            throw new Error(`Function handler for ${fnSpec.name} not implemented`);
        }
        let argOBj;
        if (func.args && func.args.length > 0) {
            argOBj = JSON5.parse(func.args);
        }
        if (!fnSpec.parameters) {
            const res = fnSpec.func.length === 1
                ? await fnSpec.func(options)
                : await fnSpec.func();
            return {
                name: fnSpec.name,
                result: JSON.stringify(res, null, 2)
            };
        }
        const res = fnSpec.func.length === 2
            ? await fnSpec.func(argOBj, options)
            : await fnSpec.func(argOBj);
        return {
            id: func.id,
            name: func.name,
            args: func.args,
            result: JSON.stringify(res, null, 2)
        };
    };
    execute = async (func, options) => {
        const fnSpec = this.funcList.find((v) => v.name.localeCompare(func.name) === 0);
        if (!fnSpec) {
            throw new Error(`Function not found: ` + func.name);
        }
        if (!fnSpec.func) {
            throw new Error('No handler for function: ' + func.name);
        }
        // execute value function calls
        const funcExec = await this.executeFunction(fnSpec, func, options);
        // // signal error if no data returned
        // if (!funcExec.result || funcExec.result.length === 0) {
        //   funcExec.result = `No data returned by function`;
        // }
        return funcExec;
    };
}
//# sourceMappingURL=functions.js.map