/**
 * A memory class to store ai interactions
 * @export
 */
export class Memory {
    data = [];
    sdata = new Map();
    limit;
    constructor(limit = 50) {
        if (limit <= 0) {
            throw Error("argument 'last' must be greater than 0");
        }
        this.limit = limit;
    }
    add(value, sessionId) {
        const d = this.get(sessionId);
        let n = 0;
        if (Array.isArray(value)) {
            n = d.push(...structuredClone(value));
        }
        else {
            n = d.push({
                ...structuredClone(value)
            });
        }
        if (d.length > this.limit) {
            d.splice(0, this.limit + n - this.limit);
        }
    }
    addResult({ content, name, functionCalls }, sessionId) {
        this.add({ content, name, role: 'assistant', functionCalls }, sessionId);
    }
    updateResult({ content, name, functionCalls }, sessionId) {
        const item = this.get(sessionId);
        if ('content' in item && content) {
            item.content = content;
        }
        if ('name' in item && name) {
            item.name = name;
        }
        if ('functionCalls' in item && functionCalls) {
            item.functionCalls = functionCalls;
        }
    }
    history(sessionId) {
        return this.get(sessionId);
    }
    peek(sessionId) {
        return this.get(sessionId);
    }
    getLast(sessionId) {
        const d = this.get(sessionId);
        return d.at(-1);
    }
    reset(sessionId) {
        if (!sessionId) {
            this.data = [];
        }
        else {
            this.sdata.set(sessionId, []);
        }
    }
    get(sessionId) {
        if (!sessionId) {
            return this.data;
        }
        if (!this.sdata.has(sessionId)) {
            this.sdata.set(sessionId, []);
        }
        return this.sdata.get(sessionId) || [];
    }
}
//# sourceMappingURL=memory.js.map