/// <reference types="node" />
/// <reference types="node" />
import type { ReadableStream } from 'stream/web';
import type { EmbedResponse, RateLimiterFunction, TextModelConfig, TextModelInfo, TextResponse, TextResponseResult } from '../ai/types.js';
import type { Tracer } from '../trace/index.js';
import type { AITextChatRequest, AITextEmbedRequest } from '../types/index.js';
export type FunctionExec = {
    id?: string;
    name: string;
    args?: any;
    result?: string;
};
export type AITextResponse<T> = {
    prompt: string;
    sessionId?: string;
    value(): T;
};
export interface AIMemory {
    add(result: Readonly<AITextChatRequest['chatPrompt'] | AITextChatRequest['chatPrompt'][0]>, sessionId?: string): void;
    addResult(result: Readonly<TextResponseResult>, sessionId?: string): void;
    updateResult(result: Readonly<TextResponseResult>, sessionId?: string): void;
    history(sessionId?: string): AITextChatRequest['chatPrompt'];
    peek(sessionId?: string): AITextChatRequest['chatPrompt'];
    reset(sessionId?: string): void;
    getLast(sessionId?: string): AITextChatRequest['chatPrompt'][0] | undefined;
}
export type AIPromptConfig = {
    stream?: boolean;
};
export type AITranscribeConfig = {
    language?: string;
};
export type AIServiceOptions = {
    debug?: boolean;
    rateLimiter?: RateLimiterFunction;
    fetch?: typeof fetch;
    tracer?: Tracer;
};
export type AIServiceActionOptions = {
    sessionId?: string;
    traceId?: string;
};
export interface AIService {
    getName(): string;
    getModelInfo(): Readonly<TextModelInfo & {
        provider: string;
    }>;
    getEmbedModelInfo(): Readonly<TextModelInfo> | undefined;
    getModelConfig(): Readonly<TextModelConfig>;
    getFeatures(): {
        functions: boolean;
        streaming: boolean;
    };
    chat(req: Readonly<AITextChatRequest>, options?: Readonly<AIPromptConfig & AIServiceActionOptions>): Promise<TextResponse | ReadableStream<TextResponse>>;
    embed(req: Readonly<AITextEmbedRequest>, options?: Readonly<AIServiceActionOptions & AIServiceActionOptions>): Promise<EmbedResponse>;
    setOptions(options: Readonly<AIServiceOptions>): void;
}
