import type { TextModelConfig, TextModelInfo, TextResponseResult, TokenUsage } from '../ai/types.js';
import type { AITextChatRequest, AITextEmbedRequest, AITextRequestIdentity, AITextTraceStep, AITextTraceStepRequest, AITextTraceStepResponse, APIError, ParsingError, TextModelInfoWithProvider } from './types.js';
export declare class ModelInfoBuilder {
    private info;
    setName(name: string): this;
    setCurrency(currency: string): this;
    setCharacterIsToken(characterIsToken: boolean): this;
    setPromptTokenCostPer1M(promptTokenCostPer1M: number): this;
    setCompletionTokenCostPer1M(completionTokenCostPer1M: number): this;
    setProvider(provider: string): this;
    build(): TextModelInfo & {
        provider: string;
    };
}
export declare class ModelConfigBuilder {
    private config;
    setMaxTokens(maxTokens: number): this;
    setTemperature(temperature: number): this;
    setTopP(topP: number): this;
    setTopK(topK: number): this;
    setN(n: number): this;
    setStream(stream: boolean): this;
    setLogprobs(logprobs: number): this;
    setEcho(echo: boolean): this;
    setPresencePenalty(presencePenalty: number): this;
    setFrequencyPenalty(frequencyPenalty: number): this;
    setBestOf(bestOf: number): this;
    setLogitBias(logitBias: ReadonlyMap<string, number>): this;
    setSuffix(suffix: string | null): this;
    build(): TextModelConfig;
}
export declare class TextResponseBuilder {
    private response;
    setResults(results?: readonly TextResponseResult[]): this;
    setModelUsage(modelUsage?: Readonly<TokenUsage>): this;
    setEmbedModelUsage(embedModelUsage?: Readonly<TokenUsage>): this;
    setRemoteId(remoteId?: string): this;
    setModelResponseTime(modelResponseTime?: number): this;
    setEmbedModelResponseTime(embedModelResponseTime?: number): this;
    setParsingError(parsingError?: Readonly<ParsingError>): this;
    setApiError(apiError?: Readonly<APIError>): this;
    build(): AITextTraceStepResponse;
}
export declare class TextRequestBuilder {
    private request;
    setChatStep(req: Readonly<AITextChatRequest>, modelConfig?: Readonly<TextModelConfig>, modelInfo?: Readonly<TextModelInfoWithProvider>): this;
    addChat(chat: Readonly<AITextChatRequest['chatPrompt'][0]>): this;
    setFunctionCall(functionCall: Readonly<AITextChatRequest['functionCall']>): this;
    setEmbedStep(req: Readonly<AITextEmbedRequest>, modelInfo?: Readonly<TextModelInfoWithProvider>): this;
    setIdentity(identity?: Readonly<AITextRequestIdentity>): this;
    build(): Readonly<AITextTraceStepRequest>;
}
export declare class AITextTraceStepBuilder {
    private traceStep;
    setTraceId(traceId?: string): this;
    setSessionId(sessionId?: string): this;
    setRequest(request: Readonly<TextRequestBuilder>): this;
    setResponse(response: Readonly<TextResponseBuilder>): this;
    setModelResponseTime(modelResponseTime?: number): this;
    setApiError(apiError?: Readonly<APIError>): this;
    build(): AITextTraceStep;
    isStream(): boolean;
}
export declare const sendTrace: (endpoint: string, headers: Readonly<Record<string, string>>, step: Readonly<AITextTraceStep>) => Promise<void>;
export declare const getMemory: (endpoint: string, headers: Readonly<Record<string, string>>, filter: Readonly<{
    sessionId?: string;
    user?: string;
    limit?: number;
}>) => Promise<{
    role?: string;
    text: string;
}[]>;
