import { TransformStream } from 'stream/web';
class TextDecodeTransformer {
    decoder;
    constructor() {
        this.decoder = new TextDecoder();
    }
    transform(chunk, controller) {
        if (!(chunk instanceof ArrayBuffer || ArrayBuffer.isView(chunk))) {
            throw new TypeError('Input data must be a BufferSource');
        }
        const text = this.decoder.decode(chunk, { stream: true });
        if (text.length !== 0) {
            controller.enqueue(text);
        }
    }
    flush(controller) {
        const text = this.decoder.decode();
        if (text.length !== 0) {
            controller.enqueue(text);
        }
    }
}
export class TextDecoderStreamPolyfill extends TransformStream {
    constructor() {
        super(new TextDecodeTransformer());
    }
}
//# sourceMappingURL=stream.js.map