import { TransformStream } from 'stream/web';
class JSONTransformer {
    async transform(obj, controller) {
        (obj.split('\n') ?? [])
            .map(extractJson)
            .map((v) => {
            try {
                return v && v.length > 0 ? JSON.parse(v) : null;
            }
            catch (e) {
                return null;
            }
        })
            .filter((v) => v)
            .forEach((v) => v && controller.enqueue(v));
    }
}
export class JSONStringifyStream extends TransformStream {
    constructor() {
        super(new JSONTransformer());
    }
}
class TypeTransformer {
    buffer;
    doneCallback;
    transformFn;
    constructor(transformFn, doneCallback) {
        this.transformFn = transformFn;
        this.doneCallback = doneCallback;
        this.buffer = doneCallback ? [] : undefined;
    }
    async transform(obj, controller) {
        const val = this.transformFn(obj);
        if (val) {
            controller.enqueue(val);
            this.buffer?.push(val);
        }
    }
    async flush(controller) {
        await this.doneCallback?.(this.buffer ?? []);
        controller.terminate();
    }
}
export class RespTransformStream extends TransformStream {
    constructor(transformFn, doneCallback) {
        super(new TypeTransformer(transformFn, doneCallback));
    }
}
const extractJson = (str) => {
    const startIndex = str.indexOf('{');
    const endIndex = str.lastIndexOf('}');
    if (startIndex !== -1 && endIndex !== -1) {
        return str.substring(startIndex, endIndex + 1);
    }
    return null;
};
//# sourceMappingURL=transform.js.map